=============================
TheLadder
=============================

.. image:: https://travis-ci.org/six0h/TheLadder.png?branch=master
    :target: https://travis-ci.org/six0h/TheLadder

.. image:: https://pypip.in/d/TheLadder/badge.png
    :target: https://pypi.python.org/pypi/TheLadder


A competitive ladder app in Python.


Features
--------

* View Leaderboard
* See ladder Schedule
* Challenge other players
